@@ -8,8 +8,6 @@
 #' @param df1 A data frame.
 #' @param df2 An optional second data frame with which to comparing memory usage.  
 #' Defaults to \code{NULL}.
-#' @param show_plot (Deprecated) Logical flag indicating whether a plot should be shown.  
-#' Superseded by the function \code{show_plot()} and will be dropped in a future version.
 #' @return A tibble summarising and comparing the columnwise memory usage 
 #' for one or a pair of data frames.
 #' @details 
@@ -64,7 +62,7 @@
 #' @importFrom magrittr %>%
 #' @importFrom tibble tibble
 
-inspect_mem <- function(df1, df2 = NULL, show_plot = FALSE){
+inspect_mem <- function(df1, df2 = NULL){
   
   # perform basic column check on dataframe input
   input_type <- check_df_cols(df1, df2)
@@ -120,6 +118,5 @@ inspect_mem <- function(df1, df2 = NULL, show_plot = FALSE){
   attr(out, "type")     <- list(method = "mem", input_type = input_type)
   attr(out, "df_names") <- df_names
   attr(out, "sizes")    <- sizes
-  if(show_plot) plot_deprecated(out)
   return(out)
 }
