@@ -16,6 +16,7 @@
                              "cls", "alpha", "jsd", "significant", "bar_width", 
                              "corr_1", "corr_2", "data_frame_n", "col_vec", "size", 
                              "df_cat_fact", "ymax", "se", "col_name1", "prop_z", 
-                             "data", "pcnt_nna", "bytes"))
+                             "data", "pcnt_nna", "bytes", "md_cor", "md_pcnt",
+                             "nna", 'breaks'))
   invisible()
 }
\ No newline at end of file
